.. _dialogs:

Dialogs
=======

Usage Pattern
-------------

Creation Functions
------------------

.. autofunction:: qtrio.dialogs.create_integer_dialog
.. autofunction:: qtrio.dialogs.create_text_input_dialog
.. autofunction:: qtrio.dialogs.create_file_save_dialog
.. autofunction:: qtrio.dialogs.create_message_box


Classes
-------

.. autoclass:: qtrio.dialogs.IntegerDialog
   :members:

.. autoclass:: qtrio.dialogs.TextInputDialog
   :members:

.. autoclass:: qtrio.dialogs.FileDialog
   :members:

.. autoclass:: qtrio.dialogs.MessageBox
   :members:


Protocol
--------

.. autoclass:: qtrio.dialogs.DialogProtocol
   :members:

.. autofunction:: qtrio.dialogs.check_dialog_protocol
